Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(332)

Unified Diff: build/android/emulator.py

Issue 10696170: Fix SDK installer by downloading r20 directly (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | build/install-build-deps-android-sdk.sh » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: build/android/emulator.py
diff --git a/build/android/emulator.py b/build/android/emulator.py
index 18f190eda87d28663e83609d555bcca399c311f2..f652fe6e131cb9848f91395020a5736f643099e3 100755
--- a/build/android/emulator.py
+++ b/build/android/emulator.py
@@ -9,7 +9,7 @@
Assumes system environment ANDROID_NDK_ROOT has been set.
Emulator: The class provides the methods to launch/shutdown the emulator with
the android virtual device named 'buildbot' .
"""
import logging
@@ -86,7 +86,7 @@ def _GetAvailablePort():
class Emulator(object):
"""Provides the methods to lanuch/shutdown the emulator.
The emulator has the android virtual device named 'buildbot'.
The emulator could use any even TCP port between 5554 and 5584 for the
console communication, and this port will be part of the device name like
@@ -156,7 +156,7 @@ class Emulator(object):
# That's not enough for 8 unit test bundles and their data.
'-partition-size', '512',
# Use a familiar name and port.
- '-avd', 'buildbot',
+ '-avd', 'avd_armeabi',
'-port', str(port)]
if not self.fast_and_loose:
emulator_command.extend([
@@ -9,7 +9,7 @@
Assumes system environment ANDROID_NDK_ROOT has been set.
Emulator: The class provides the methods to launch/shutdown the emulator with
- the android virtual device named 'buildbot' .
+ the android virtual device named 'avd_armeabi' .
"""
import logging
@@ -86,7 +86,7 @@ def _GetAvailablePort():
class Emulator(object):
"""Provides the methods to lanuch/shutdown the emulator.
- The emulator has the android virtual device named 'buildbot'.
+ The emulator has the android virtual device named 'avd_armeabi'.
The emulator could use any even TCP port between 5554 and 5584 for the
console communication, and this port will be part of the device name like
« no previous file with comments | « no previous file | build/install-build-deps-android-sdk.sh » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698